@@ -1,9 +1,7 @@
 package DBIx::OnlineDDL::Helper::SQLite;
 
 our $AUTHORITY = 'cpan:GSG';
-# ABSTRACT: Private OnlineDDL helper for SQLite-specific code
-use version;
-our $VERSION = 'v0.940.0'; # VERSION
+our $VERSION   = '0.90';
 
 use v5.10;
 use Moo;
@@ -12,22 +10,31 @@ extends 'DBIx::OnlineDDL::Helper::Base';
 
 use Types::Standard qw( InstanceOf );
 
+use DBI::Const::GetInfoType;
 use Sub::Util qw( set_subname );
 
 use namespace::clean;  # don't export the above
 
-#pod =encoding utf8
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod This is a private helper module for any SQLite-specific code.  B<As a private module, any
-#pod methods or attributes here are subject to change.>
-#pod
-#pod You should really be reading documentation for L<DBIx::OnlineDDL>.  Or, if you want to
-#pod create a helper module for a different RDBMS, read the docs for
-#pod L<DBIx::OnlineDDL::Helper::Base>.
-#pod
-#pod =cut
+=encoding utf8
+
+=head1 NAME
+
+DBIx::OnlineDDL::Helper::SQLite - Private OnlineDDL helper for SQLite-specific code
+
+=head1 VERSION
+
+version 0.90
+
+=head1 DESCRIPTION
+
+This is a private helper module for any SQLite-specific code.  B<As a private module, any
+methods or attributes here are subject to change.>
+
+You should really be reading documentation for L<DBIx::OnlineDDL>.  Or, if you want to
+create a helper module for a different RDBMS, read the docs for
+L<DBIx::OnlineDDL::Helper::Base>.
+
+=cut
 
 sub dbms_uses_global_fk_namespace { 0 }
 sub child_fks_need_adjusting      { 0 }
@@ -66,7 +73,7 @@ sub post_connection_stmts {
     my $self = shift;
 
     my $db_timeouts = $self->db_timeouts;
-    my @stmts = (
+    return (
         # See FK comment in MySQL module.  FKs in SQLite are a per-connection enabled
         # feature, so this is always a "session" command.
         'PRAGMA foreign_keys = OFF',
@@ -74,17 +81,6 @@ sub post_connection_stmts {
         # DB timeouts
         'PRAGMA busy_timeout = '.int($db_timeouts->{lock_file} * 1_000),  # busy_timeout uses ms
     );
-
-    # SQLite version 3.25.0 fixes table renames to also rename references to the table,
-    # ie: child FKs.  Since SQLite doesn't yet have an DDL statement for renaming the FKs
-    # back to the old name, setting this PRAGMA variable is the only option.
-    #
-    # Also, while this change was introduced in 3.25.0, it seems to only manifest itself
-    # when the driver reports version 3.26.0, possibly due to how their production
-    # releases work.
-    push @stmts, 'PRAGMA legacy_alter_table = ON' if $self->mmver >= 3.026;
-
-    return @stmts;
 }
 
 sub is_error_retryable {
@@ -118,7 +114,7 @@ sub create_table_sql {
 
 # Keep Base->rename_fks_in_table_sql (not used)
 
-sub has_conflicting_triggers_on_table {
+sub has_triggers_on_table {
     my ($self, $table_name) = @_;
 
     return $self->dbh_runner(run => set_subname '_has_triggers_on_table', sub {
@@ -154,41 +150,20 @@ sub analyze_table {
 
 # Keep the other FK methods (not used)
 
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-DBIx::OnlineDDL::Helper::SQLite - Private OnlineDDL helper for SQLite-specific code
-
-=head1 VERSION
-
-version v0.940.0
-
-=head1 DESCRIPTION
-
-This is a private helper module for any SQLite-specific code.  B<As a private module, any
-methods or attributes here are subject to change.>
-
-You should really be reading documentation for L<DBIx::OnlineDDL>.  Or, if you want to
-create a helper module for a different RDBMS, read the docs for
-L<DBIx::OnlineDDL::Helper::Base>.
-
 =head1 AUTHOR
 
 Grant Street Group <developers@grantstreet.com>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2018 - 2021 by Grant Street Group.
+Copyright 2018 Grant Street Group
 
-This is free software, licensed under:
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
 
-  The Artistic License 2.0 (GPL Compatible)
+L<http://www.perlfoundation.org/artistic_license_2_0>
 
 =cut
+
+1;
